==> order-api-lm-1.1.15-20230621.025127-2-sources.jar: com/elitesland/yst/lm/order/rpc/LmSaleDoRpcService.java <==
package com.elitesland.yst.lm.order.rpc;

import com.elitesland.yst.lm.order.Application;
import com.elitesland.yst.lm.order.rpc.param.query.LmSalDoQueryDTO;
import com.elitesland.yst.lm.order.rpc.param.query.LmUnShippedQueryDTO;
import com.elitesland.yst.lm.order.rpc.param.resp.LmSalDoPerforRespDTO;
import com.elitesland.yst.lm.order.rpc.param.resp.LmSalDoRespDTO;
import com.elitesland.yst.lm.order.rpc.param.resp.LmUnShippedRespDTO;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

/**
 * @Author: ryan.xu
 * @since 2023/3/25
 */
@FeignClient(name = Application.NAME, path = LmSaleDoRpcService.URI)
@Validated
public interface LmSaleDoRpcService {

    String URI = Application.URI_PREFIX + "/salDo";

    /**
     * 发货单查询
     *
     * @param param
     * @return
     */
    @PostMapping("/query")
    LmSalDoRespDTO querySalDo(@RequestBody LmSalDoQueryDTO param);

    /**
     * 未发货单查询
     *
     * @param param
     * @return
     */
    @PostMapping("/unShipped/query")
    LmUnShippedRespDTO queryUnShippedOrder(@RequestBody LmUnShippedQueryDTO param);

    /**
     * 查询销售业绩统计数据
     * @param dateStr
     * @return
     */
    @PostMapping("/querySalePerfor")
    List<LmSalDoPerforRespDTO> querySalePerfor(@RequestParam("dateStr") String dateStr);
}

==> order-api-lm-1.1.56-20240708.014637-1-sources.jar: com/elitesland/yst/lm/order/rpc/LmSaleDoRpcService.java <==
package com.elitesland.yst.lm.order.rpc;

import com.elitesland.yst.lm.order.Application;
import com.elitesland.yst.lm.order.rpc.param.query.LmSalDoQueryDTO;
import com.elitesland.yst.lm.order.rpc.param.query.LmUnShippedQueryDTO;
import com.elitesland.yst.lm.order.rpc.param.resp.LmSalDoPerforRespDTO;
import com.elitesland.yst.lm.order.rpc.param.resp.LmSalDoRespDTO;
import com.elitesland.yst.lm.order.rpc.param.resp.LmUnShippedRespDTO;
import com.elitesland.yst.lm.order.rpc.param.resp.VehicleNoInfoVO;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

/**
 * @Author: ryan.xu
 * @since 2023/3/25
 */
@FeignClient(name = Application.NAME, path = LmSaleDoRpcService.URI)
@Validated
public interface LmSaleDoRpcService {

    String URI = Application.URI_PREFIX + "/salDo";

    /**
     * 发货单查询
     *
     * @param param
     * @return
     */
    @PostMapping("/query")
    LmSalDoRespDTO querySalDo(@RequestBody LmSalDoQueryDTO param);

    /**
     * 未发货单查询
     *
     * @param param
     * @return
     */
    @PostMapping("/unShipped/query")
    LmUnShippedRespDTO queryUnShippedOrder(@RequestBody LmUnShippedQueryDTO param);

    /**
     * 查询销售业绩统计数据
     * @param dateStr
     * @return
     */
    @PostMapping("/querySalePerfor")
    List<LmSalDoPerforRespDTO> querySalePerfor(@RequestParam("dateStr") String dateStr);

    /**
     * 根据车架号查询发货单车辆信息
     * @param vehicleNo
     * @return
     */
    @PostMapping("/queryVehicleNoInfo")
    VehicleNoInfoVO queryVehicleNoInfo(@RequestParam("vehicleNo") String vehicleNo);

    @PostMapping("/vehicleBelongCust")
    Boolean vehicleBelongCust(@RequestParam("vehicleNo") String vehicleNo, @RequestParam("custCode") String custCode);
}
